<?php

namespace Litepie\Campaign\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\Campaign\Http\Requests\CampaignVariantRequest;
use Litepie\Campaign\Interfaces\CampaignVariantRepositoryInterface;
use Litepie\Campaign\Models\CampaignVariant;

/**
 * Resource controller class for campaign_variant.
 */
class CampaignVariantResourceController extends BaseController
{

    /**
     * Initialize campaign_variant resource controller.
     *
     * @param type CampaignVariantRepositoryInterface $campaign_variant
     *
     * @return null
     */
    public function __construct(CampaignVariantRepositoryInterface $campaign_variant)
    {
        parent::__construct();
        $this->repository = $campaign_variant;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Campaign\Repositories\Criteria\CampaignVariantResourceCriteria::class);
    }

    /**
     * Display a list of campaign_variant.
     *
     * @return Response
     */
    public function index(CampaignVariantRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\Campaign\Repositories\Presenter\CampaignVariantPresenter::class)
                ->$function();
        }

        $campaign_variants = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('campaign::campaign_variant.names'))
            ->view('campaign::campaign_variant.index', true)
            ->data(compact('campaign_variants', 'view'))
            ->output();
    }

    /**
     * Display campaign_variant.
     *
     * @param Request $request
     * @param Model   $campaign_variant
     *
     * @return Response
     */
    public function show(CampaignVariantRequest $request, CampaignVariant $campaign_variant)
    {

        if ($campaign_variant->exists) {
            $view = 'campaign::campaign_variant.show';
        } else {
            $view = 'campaign::campaign_variant.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('campaign::campaign_variant.name'))
            ->data(compact('campaign_variant'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new campaign_variant.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CampaignVariantRequest $request)
    {

        $campaign_variant = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('campaign::campaign_variant.name')) 
            ->view('campaign::campaign_variant.create', true) 
            ->data(compact('campaign_variant'))
            ->output();
    }

    /**
     * Create new campaign_variant.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CampaignVariantRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $campaign_variant                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('campaign::campaign_variant.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('campaign/campaign_variant/' . $campaign_variant->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/campaign/campaign_variant'))
                ->redirect();
        }

    }

    /**
     * Show campaign_variant for editing.
     *
     * @param Request $request
     * @param Model   $campaign_variant
     *
     * @return Response
     */
    public function edit(CampaignVariantRequest $request, CampaignVariant $campaign_variant)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('campaign::campaign_variant.name'))
            ->view('campaign::campaign_variant.edit', true)
            ->data(compact('campaign_variant'))
            ->output();
    }

    /**
     * Update the campaign_variant.
     *
     * @param Request $request
     * @param Model   $campaign_variant
     *
     * @return Response
     */
    public function update(CampaignVariantRequest $request, CampaignVariant $campaign_variant)
    {
        try {
            $attributes = $request->all();

            $campaign_variant->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('campaign::campaign_variant.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('campaign/campaign_variant/' . $campaign_variant->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('campaign/campaign_variant/' . $campaign_variant->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the campaign_variant.
     *
     * @param Model   $campaign_variant
     *
     * @return Response
     */
    public function destroy(CampaignVariantRequest $request, CampaignVariant $campaign_variant)
    {
        try {

            $campaign_variant->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('campaign::campaign_variant.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('campaign/campaign_variant/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('campaign/campaign_variant/' . $campaign_variant->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple campaign_variant.
     *
     * @param Model   $campaign_variant
     *
     * @return Response
     */
    public function delete(CampaignVariantRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('campaign::campaign_variant.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('campaign/campaign_variant'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/campaign/campaign_variant'))
                ->redirect();
        }

    }

    /**
     * Restore deleted campaign_variants.
     *
     * @param Model   $campaign_variant
     *
     * @return Response
     */
    public function restore(CampaignVariantRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('campaign::campaign_variant.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/campaign/campaign_variant'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/campaign/campaign_variant/'))
                ->redirect();
        }

    }

}
